@@ -556,6 +556,9 @@ about (BonoboUIComponent *uic,
   const gchar *translator_credits = _("translator_credits");
 
   if (curr_data->about_dialog) {
+	gtk_window_set_screen (GTK_WINDOW (curr_data->about_dialog),
+			       gtk_widget_get_screen (curr_data->applet));
+
 	gtk_window_present (GTK_WINDOW (curr_data->about_dialog));
 	return;
   }
