@@ -197,20 +197,20 @@ GSwitchItAppletFilterXEvt (GdkXEvent * xev,
 	XEvent *xevent = (XEvent *) xev;
 	Display *display = xevent->xany.display;
 	XklFilterEvents (xevent);
-	switch ( xevent->type )
-	{
-		case ReparentNotify:
+	switch (xevent->type) {
+	case ReparentNotify:
 		{
-			XReparentEvent *rne = ( XReparentEvent * ) xev;
+			XReparentEvent *rne = (XReparentEvent *) xev;
 			GtkWidget *w1;
 			GdkWindow *w;
-			w1 = gtk_widget_get_ancestor( sia->applet, GTK_TYPE_WINDOW );
-			if( w1 == NULL )
+			w1 = gtk_widget_get_ancestor (sia->applet,
+						      GTK_TYPE_WINDOW);
+			if (w1 == NULL)
 				break;
 			w = w1->window;
-			if( w == NULL || GDK_WINDOW_XID( w ) != rne->window )
+			if (w == NULL || GDK_WINDOW_XID (w) != rne->window)
 				break;
-			XklSetTransparent( GDK_WINDOW_XID( w ), TRUE );
+			XklSetTransparent (GDK_WINDOW_XID (w), TRUE);
 		}
 		break;
 	}
@@ -265,11 +265,12 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 {
 	GdkPixbuf *image = sia->appletConfig.images[group];
 	GdkPixbuf *scaled;
-	GtkWidget *groupDrawingArea;
 	PanelAppletOrient orient;
 	int psize, xsize = 0, ysize = 0;
 	double xyratio;
+	sia->ebox = gtk_event_box_new ();
 	if (sia->appletConfig.showFlags) {
+		GtkWidget *flagImg;
 		if (image == NULL)
 			return NULL;
 		orient =
@@ -295,11 +296,13 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 		scaled =
 		    gdk_pixbuf_scale_simple (image, xsize, ysize,
 					     GDK_INTERP_HYPER);
-		groupDrawingArea = gtk_image_new_from_pixbuf (scaled);
+		flagImg = gtk_image_new_from_pixbuf (scaled);
+		gtk_container_add (GTK_CONTAINER (sia->ebox), flagImg);
 		g_object_unref (G_OBJECT (scaled));
-		sia->ebox = NULL;	// not used in this case!
+		//sia->ebox = NULL;	// not used in this case!
 	} else {
 		char *layoutName;
+		char *allocLayoutName = NULL;
 		XklConfigItem configItem;
 		GtkWidget *align, *label;
 
@@ -319,31 +322,34 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 
 			if (XklConfigFindLayout (&configItem)) {
 				char *sd = configItem.shortDescription;
-				if (sd != NULL && *sd != '\0')
-					layoutName = sd;
+				if (sd != NULL && *sd != '\0') {
+					layoutName = allocLayoutName =
+					    g_locale_to_utf8 (sd, -1, NULL,
+							      NULL, NULL);
+				}
 			}
 		} else
 			layoutName = sia->groupNames[group];
 		align = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
 		label = gtk_label_new (layoutName);
-		sia->ebox = gtk_event_box_new ();
-		groupDrawingArea = sia->ebox;
-		g_signal_connect (G_OBJECT (sia->ebox),
-				  "button_press_event",
-				  G_CALLBACK
-				  (GSwitchItAppletButtonPressed), sia);
-
-		g_signal_connect (G_OBJECT (sia->applet),
-				  "key_press_event",
-				  G_CALLBACK
-				  (GSwitchItAppletKeyPressed), sia);
-
+		if (allocLayoutName != NULL)
+			g_free (allocLayoutName);
 		gtk_container_add (GTK_CONTAINER (align), label);
 		gtk_container_add (GTK_CONTAINER (sia->ebox), align);
 
 		gtk_container_set_border_width (GTK_CONTAINER (align), 2);
 	}
-	return groupDrawingArea;
+	g_signal_connect (G_OBJECT (sia->ebox),
+			  "button_press_event",
+			  G_CALLBACK
+			  (GSwitchItAppletButtonPressed), sia);
+
+	g_signal_connect (G_OBJECT (sia->applet),
+			  "key_press_event",
+			  G_CALLBACK
+			  (GSwitchItAppletKeyPressed), sia);
+
+	return sia->ebox;
 }
 
 static void
@@ -475,6 +481,7 @@ GSwitchItAppletButtonPressed (GtkWidget *
 			      event, GSwitchItAppletConfig * config)
 {
 	if (event->button == 1 && event->type == GDK_BUTTON_PRESS) {
+		XklDebug (150, "Mouse button pressed on applet\n");
 		GSwitchItAppletConfigLockNextGroup ();
 		return TRUE;
 	}
