@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.77 2004/02/29 08:19:19 dsmit Exp $ */
+/* $Id: gweather-applet.c,v 1.78.2.1 2004/06/08 12:07:09 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -259,6 +259,36 @@ applet_destroy (GtkWidget *widget, GWeatherApplet *gw_applet)
 
     if (gw_applet->gweather_dialog)
        gtk_widget_destroy (gw_applet->gweather_dialog);
+
+    if (gw_applet->timeout_tag > 0) {
+       gtk_timeout_remove(gw_applet->timeout_tag);
+       gw_applet->timeout_tag = 0;
+    }
+	
+    if (gw_applet->gweather_info->metar_handle) {
+       gnome_vfs_async_cancel(gw_applet->gweather_info->metar_handle);
+       gw_applet->gweather_info->metar_handle = 0;
+    }
+
+    if (gw_applet->gweather_info->iwin_handle) {
+       gnome_vfs_async_cancel(gw_applet->gweather_info->iwin_handle);
+       gw_applet->gweather_info->iwin_handle = 0;
+    }
+
+    if (gw_applet->gweather_info->wx_handle) {
+       gnome_vfs_async_cancel(gw_applet->gweather_info->wx_handle);
+       gw_applet->gweather_info->wx_handle = 0;
+    }
+
+    if (gw_applet->gweather_info->met_handle) {
+       gnome_vfs_async_cancel(gw_applet->gweather_info->met_handle);
+       gw_applet->gweather_info->met_handle = 0;
+    }
+
+    if (gw_applet->gweather_info->bom_handle) {
+       gnome_vfs_async_cancel(gw_applet->gweather_info->bom_handle);
+       gw_applet->gweather_info->bom_handle = 0;
+    }
 }
 
 void gweather_applet_create (GWeatherApplet *gw_applet)
@@ -285,7 +315,7 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
         gtk_icon_info_free (icon_info);
     }
 
-    gw_applet->container = gtk_hbox_new (FALSE, 0);
+    gw_applet->container = gtk_alignment_new(0.5, 0.5, 0, 0);
     gtk_container_add (GTK_CONTAINER (gw_applet->applet), gw_applet->container);
 
     g_signal_connect (G_OBJECT(gw_applet->applet), "change_orient",
