@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.75 2004/04/25 18:19:33 kevinv Exp $ */
+/* $Id: weather.c,v 1.75.2.4 2004/06/09 06:59:00 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -298,7 +298,7 @@ close_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data)
 #define TIME_RE_STR  "^([0-9]{6})Z$"
 #define WIND_RE_STR  "^(([0-9]{3})|VRB)([0-9]?[0-9]{2})(G[0-9]?[0-9]{2})?KT$"
 #define VIS_RE_STR   "^(([0-9]?[0-9])|(M?1/[0-9]?[0-9]))SM$"
-#define CLOUD_RE_STR "^(CLR|BKN|SCT|FEW|OVC|SKC)([0-9]{3})?$"
+#define CLOUD_RE_STR "^(CLR|BKN|SCT|FEW|OVC|SKC|NSC)([0-9]{3})?(CB|TCU)?$"
 #define TEMP_RE_STR  "^(M?[0-9][0-9])/(M?(//|[0-9][0-9]))$"
 #define PRES_RE_STR  "^(A|Q)([0-9]{4})$"
 #define COND_RE_STR  "^(-|\\+)?(VC|MI|BC|PR|TS|BL|SH|DR|FZ)?(DZ|RA|SN|SG|IC|PE|GR|GS|UP|BR|FG|FU|VA|SA|HZ|PY|DU|SQ|SS|DS|PO|\\+?FC)$"
@@ -546,6 +546,8 @@ static gboolean metar_tok_cloud (gchar *tokp, WeatherInfo *info)
         info->sky = SKY_CLEAR;
     } else if (!strcmp(stype, "SKC")) {
         info->sky = SKY_CLEAR;
+    } else if (!strcmp(stype, "NSC")) {
+        info->sky = SKY_CLEAR;
     } else if (!strcmp(stype, "BKN")) {
         info->sky = SKY_BROKEN;
     } else if (!strcmp(stype, "SCT")) {
@@ -1684,6 +1686,8 @@ gboolean _weather_info_fill (GWeatherApplet *applet, WeatherInfo *info, WeatherL
     	info->requests_pending = FALSE;
     	info->metar_buffer = NULL;
     	info->iwin_buffer = NULL; 
+        info->met_buffer = NULL;
+        info->bom_buffer = NULL;
     	info->location = weather_location_clone(location);
     } else {
         location = info->location;
@@ -1806,8 +1810,16 @@ WeatherInfo *weather_info_config_read (PanelApplet *applet)
     info->forecast = g_strdup ("None");
     info->radar = NULL;  /* FIX */
     info->requests_pending = FALSE;
+
     info->metar_buffer = NULL;
-    info->iwin_buffer = NULL; 
+    info->iwin_buffer = NULL;
+    info->met_buffer = NULL;
+    info->bom_buffer = NULL;
+
+    info->met_handle = NULL;
+    info->iwin_handle = NULL;
+    info->met_handle = NULL;
+    info->bom_handle = NULL;
 
     return info;
 }
@@ -1840,24 +1852,48 @@ WeatherInfo *weather_info_clone (const WeatherInfo *info)
 
 void weather_info_free (WeatherInfo *info)
 {
-    if (info) {
-        g_free(info->location);
-        info->location = NULL;
-        g_free(info->forecast);
-        info->forecast = NULL;
-	if (info->radar != NULL) {
-		gdk_pixmap_unref (info->radar);
-		info->radar = NULL;
-	}
-	if (info->radar)
-	    g_free (info->radar);
-	if (info->iwin_buffer)
-	    g_free (info->iwin_buffer);
-	if (info->metar_buffer)
-	    g_free (info->metar_buffer);
-	g_free(info);
+    if (!info)
+        return;
+                                                                                
+    weather_location_free(info->location);
+    info->location = NULL;
+                                                                                
+    g_free(info->forecast);
+    info->forecast = NULL;
+                                                                                
+    if (info->radar != NULL) {
+        gdk_pixmap_unref (info->radar);
+        info->radar = NULL;
     }
-    
+                                                                                
+    if (info->iwin_buffer)
+        g_free (info->iwin_buffer);
+                                                                                
+    if (info->metar_buffer)
+        g_free (info->metar_buffer);
+
+    if (info->met_buffer)
+        g_free (info->met_buffer);
+
+    if (info->bom_buffer)
+        g_free (info->bom_buffer);
+
+    if (info->metar_handle)
+        gnome_vfs_async_cancel (info->metar_handle);
+                                                                                
+    if (info->iwin_handle)
+        gnome_vfs_async_cancel (info->iwin_handle);
+                                                                                
+    if (info->wx_handle)
+        gnome_vfs_async_cancel (info->wx_handle);
+                                                                                
+    if (info->met_handle)
+        gnome_vfs_async_cancel (info->met_handle);
+                                                                                
+    if (info->bom_handle)
+        gnome_vfs_async_cancel (info->bom_handle);
+                                                                                
+    g_free(info);
 }
 
 void weather_forecast_set (WeatherForecastType forecast)
