@@ -55,8 +55,7 @@ static int gconfAppletListenerId = 0;
 static int gconfImagesListenerId = 0;
 static int gconfCommandsListenerId = 0;
 
-#define KEYBOARD_CONFIG_KEY_PREFIX "/desktop/gnome/peripherals/keyboard"
-#define GSWITCHIT_CONFIG_XKB_KEY_PREFIX KEYBOARD_CONFIG_KEY_PREFIX "/xkb"
+#define GSWITCHIT_CONFIG_XKB_KEY_PREFIX "/desktop/gnome/peripherals/keyboard/xkb"
 
 const char GSWITCHIT_CONFIG_XKB_DIR[] = GSWITCHIT_CONFIG_XKB_KEY_PREFIX;
 const char GSWITCHIT_CONFIG_XKB_KEY_OVERRIDE_SETTINGS[] =
@@ -68,29 +67,6 @@ const char GSWITCHIT_CONFIG_XKB_KEY_LAYOUTS[] =
 const char GSWITCHIT_CONFIG_XKB_KEY_OPTIONS[] =
     GSWITCHIT_CONFIG_XKB_KEY_PREFIX "/options";
 
-const char *GSWITCHIT_CONFIG_XKB_ACTIVE[] = {
-	GSWITCHIT_CONFIG_XKB_KEY_MODEL,
-	GSWITCHIT_CONFIG_XKB_KEY_LAYOUTS,
-	GSWITCHIT_CONFIG_XKB_KEY_OPTIONS
-};
-
-#define GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_PREFIX KEYBOARD_CONFIG_KEY_PREFIX "/xkb.sysbackup"
-
-const char GSWITCHIT_CONFIG_XKB_SYSBACKUP_DIR[] =
-    GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_PREFIX;
-const char GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_MODEL[] =
-    GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_PREFIX "/model";
-const char GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_LAYOUTS[] =
-    GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_PREFIX "/layouts";
-const char GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_OPTIONS[] =
-    GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_PREFIX "/options";
-
-const char *GSWITCHIT_CONFIG_XKB_SYSBACKUP[] = {
-	GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_MODEL,
-	GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_LAYOUTS,
-	GSWITCHIT_CONFIG_XKB_SYSBACKUP_KEY_OPTIONS
-};
-
 static int gconfXkbListenerId;
 
 /**
@@ -437,99 +413,6 @@ _GSListStrEqual (GSList * l1, GSList * l2)
 	return (l1 == NULL && l2 == NULL);
 }
 
-static void
-_GSwitchItXkbConfigLoadParams (GSwitchItXkbConfig * xkbConfig,
-			       const char *paramNames[])
-{
-	GError *gerror = NULL;
-	gchar *pc;
-	GSList *pl;
-
-	pc = gconf_client_get_string (xkbConfig->confClient,
-				      paramNames[0], &gerror);
-	if (pc == NULL || gerror != NULL) {
-		if (gerror != NULL) {
-			g_warning ("Error reading configuration:%s\n",
-				   gerror->message);
-			g_error_free (gerror);
-			gerror = NULL;
-		}
-		GSwitchItXkbConfigModelSet (xkbConfig, NULL);
-	} else {
-		GSwitchItXkbConfigModelSet (xkbConfig, pc);
-	}
-	XklDebug (150, "Loaded XKB model: [%s]\n", xkbConfig->model);
-
-	GSwitchItXkbConfigLayoutsReset (xkbConfig);
-
-	pl = gconf_client_get_list (xkbConfig->confClient,
-				    paramNames[1],
-				    GCONF_VALUE_STRING, &gerror);
-	if (pl == NULL || gerror != NULL) {
-		if (gerror != NULL) {
-			g_warning ("Error reading configuration:%s\n",
-				   gerror->message);
-			g_error_free (gerror);
-			gerror = NULL;
-		}
-	}
-
-	while (pl != NULL) {
-		XklDebug (150, "Loaded XKB layout: [%s]\n", pl->data);
-		_GSwitchItXkbConfigLayoutsAdd (xkbConfig, pl->data);
-		pl = pl->next;
-	}
-
-	GSwitchItXkbConfigOptionsReset (xkbConfig);
-
-	pl = gconf_client_get_list (xkbConfig->confClient,
-				    paramNames[2],
-				    GCONF_VALUE_STRING, &gerror);
-	if (pl == NULL || gerror != NULL) {
-		if (gerror != NULL) {
-			g_warning ("Error reading configuration:%s\n",
-				   gerror->message);
-			g_error_free (gerror);
-			gerror = NULL;
-		}
-	}
-
-	while (pl != NULL) {
-		XklDebug (150, "Loaded XKB option: [%s]\n", pl->data);
-		_GSwitchItXkbConfigOptionsAdd (xkbConfig,
-					       (const char *) pl->data);
-		pl = pl->next;
-	}
-}
-
-static void
-_GSwitchItXkbConfigSaveParams (GSwitchItXkbConfig * xkbConfig,
-			       GConfChangeSet * cs,
-			       const char *paramNames[])
-{
-	GSList *pl;
-
-	gconf_change_set_set_string (cs, paramNames[0], xkbConfig->model);
-	XklDebug (150, "Saved XKB model: [%s]\n", xkbConfig->model);
-
-	pl = xkbConfig->layouts;
-	while (pl != NULL) {
-		XklDebug (150, "Saved XKB layout: [%s]\n", pl->data);
-		pl = pl->next;
-	}
-	gconf_change_set_set_list (cs,
-				   paramNames[1],
-				   GCONF_VALUE_STRING, xkbConfig->layouts);
-	pl = xkbConfig->options;
-	while (pl != NULL) {
-		XklDebug (150, "Saved XKB option: [%s]\n", pl->data);
-		pl = pl->next;
-	}
-	gconf_change_set_set_list (cs,
-				   paramNames[2],
-				   GCONF_VALUE_STRING, xkbConfig->options);
-}
-
 /**
  * extern xkb config functions
  */
@@ -568,6 +451,8 @@ void
 GSwitchItXkbConfigLoad (GSwitchItXkbConfig * xkbConfig)
 {
 	GError *gerror = NULL;
+	gchar *pc;
+	GSList *pl;
 
 	xkbConfig->overrideSettings =
 	    gconf_client_get_bool (xkbConfig->confClient,
@@ -583,15 +468,62 @@ GSwitchItXkbConfigLoad (GSwitchItXkbConfig * xkbConfig)
 	XklDebug (150, "Loaded XKB override cmd: [%s]\n",
 		  xkbConfig->overrideSettings ? "true" : "false");
 
-	_GSwitchItXkbConfigLoadParams (xkbConfig,
-				       GSWITCHIT_CONFIG_XKB_ACTIVE);
-}
+	pc = gconf_client_get_string (xkbConfig->confClient,
+				      GSWITCHIT_CONFIG_XKB_KEY_MODEL,
+				      &gerror);
+	if (pc == NULL || gerror != NULL) {
+		if (gerror != NULL) {
+			g_warning ("Error reading configuration:%s\n",
+				   gerror->message);
+			g_error_free (gerror);
+			gerror = NULL;
+		}
+		GSwitchItXkbConfigModelSet (xkbConfig, NULL);
+	} else {
+		GSwitchItXkbConfigModelSet (xkbConfig, pc);
+	}
+	XklDebug (150, "Loaded XKB model: [%s]\n", xkbConfig->model);
 
-void
-GSwitchItXkbConfigLoadSysBackup (GSwitchItXkbConfig * xkbConfig)
-{
-	_GSwitchItXkbConfigLoadParams (xkbConfig,
-				       GSWITCHIT_CONFIG_XKB_SYSBACKUP);
+	GSwitchItXkbConfigLayoutsReset (xkbConfig);
+
+	pl = gconf_client_get_list (xkbConfig->confClient,
+				    GSWITCHIT_CONFIG_XKB_KEY_LAYOUTS,
+				    GCONF_VALUE_STRING, &gerror);
+	if (pl == NULL || gerror != NULL) {
+		if (gerror != NULL) {
+			g_warning ("Error reading configuration:%s\n",
+				   gerror->message);
+			g_error_free (gerror);
+			gerror = NULL;
+		}
+	}
+
+	while (pl != NULL) {
+		XklDebug (150, "Loaded XKB layout: [%s]\n", pl->data);
+		_GSwitchItXkbConfigLayoutsAdd (xkbConfig, pl->data);
+		pl = pl->next;
+	}
+
+	GSwitchItXkbConfigOptionsReset (xkbConfig);
+
+	pl = gconf_client_get_list (xkbConfig->confClient,
+				    GSWITCHIT_CONFIG_XKB_KEY_OPTIONS,
+				    GCONF_VALUE_STRING, &gerror);
+	if (pl == NULL || gerror != NULL) {
+		if (gerror != NULL) {
+			g_warning ("Error reading configuration:%s\n",
+				   gerror->message);
+			g_error_free (gerror);
+			gerror = NULL;
+		}
+	}
+
+	while (pl != NULL) {
+		XklDebug (150, "Loaded XKB option: [%s]\n", pl->data);
+		_GSwitchItXkbConfigOptionsAdd (xkbConfig,
+					       (const char *) pl->data);
+		pl = pl->next;
+	}
 }
 
 void
@@ -642,6 +574,7 @@ GSwitchItXkbConfigSave (GSwitchItXkbConfig * xkbConfig)
 {
 	GConfChangeSet *cs;
 	GError *gerror = NULL;
+	GSList *pl;
 
 	cs = gconf_change_set_new ();
 	gconf_change_set_set_bool (cs,
@@ -650,35 +583,31 @@ GSwitchItXkbConfigSave (GSwitchItXkbConfig * xkbConfig)
 	XklDebug (150, "Saved XKB override cmd: [%s]\n",
 		  xkbConfig->overrideSettings ? "true" : "false");
 
-	_GSwitchItXkbConfigSaveParams (xkbConfig, cs,
-				       GSWITCHIT_CONFIG_XKB_ACTIVE);
+	gconf_change_set_set_string (cs, GSWITCHIT_CONFIG_XKB_KEY_MODEL,
+				     xkbConfig->model);
+	XklDebug (150, "Saved XKB model: [%s]\n", xkbConfig->model);
 
-	gconf_client_commit_change_set (xkbConfig->confClient, cs, TRUE,
-					&gerror);
-	if (gerror != NULL) {
-		g_warning ("Error saving active configuration: %s\n",
-			   gerror->message);
-		g_error_free (gerror);
-		gerror = NULL;
+	pl = xkbConfig->layouts;
+	while (pl != NULL) {
+		XklDebug (150, "Saved XKB layout: [%s]\n", pl->data);
+		pl = pl->next;
 	}
-	gconf_change_set_unref (cs);
-}
-
-void
-GSwitchItXkbConfigSaveSysBackup (GSwitchItXkbConfig * xkbConfig)
-{
-	GConfChangeSet *cs;
-	GError *gerror = NULL;
-
-	cs = gconf_change_set_new ();
-
-	_GSwitchItXkbConfigSaveParams (xkbConfig, cs,
-				       GSWITCHIT_CONFIG_XKB_SYSBACKUP);
+	gconf_change_set_set_list (cs,
+				   GSWITCHIT_CONFIG_XKB_KEY_LAYOUTS,
+				   GCONF_VALUE_STRING, xkbConfig->layouts);
+	pl = xkbConfig->options;
+	while (pl != NULL) {
+		XklDebug (150, "Saved XKB option: [%s]\n", pl->data);
+		pl = pl->next;
+	}
+	gconf_change_set_set_list (cs,
+				   GSWITCHIT_CONFIG_XKB_KEY_OPTIONS,
+				   GCONF_VALUE_STRING, xkbConfig->options);
 
 	gconf_client_commit_change_set (xkbConfig->confClient, cs, TRUE,
 					&gerror);
 	if (gerror != NULL) {
-		g_warning ("Error saving backup configuration: %s\n",
+		g_warning ("Error saving configuration: %s\n",
 			   gerror->message);
 		g_error_free (gerror);
 		gerror = NULL;
