@@ -78,10 +78,11 @@ typedef struct
 	GtkWidget *w_image;		/* The applet icon */
 
 	GtkWidget *about_dialog;	/* The applet it's about dialog */
-
+	GtkWidget *destroy_all_dialog;	/* The applet it's destroy all dialog */
+	
 	gboolean prelighted;		/* Whether applet is prelighted */
 	gboolean pressed;		/* Whether applet is pressed */
-	
+
 } StickyNotesApplet;
 	
 typedef enum
@@ -94,7 +95,7 @@ typedef enum
 
 extern StickyNotes *stickynotes;
 
-void stickynotes_applet_init();
+void stickynotes_applet_init(PanelApplet *panel_applet);
 void stickynotes_applet_init_icons();
 void stickynotes_applet_init_prefs();
 
@@ -105,6 +106,6 @@ void stickynotes_applet_update_prefs();
 void stickynotes_applet_update_menus();
 void stickynotes_applet_update_tooltips();
 
-void stickynotes_applet_do_default_action();
+void stickynotes_applet_do_default_action(GdkScreen *screen);
 
 #endif /* __STICKYNOTES_APPLET_H__ */
